@@ -1,5 +1,8 @@
 use structopt::StructOpt;
-use ws_tool::ConnBuilder;
+use tokio_stream::StreamExt;
+use tracing::Level;
+use tracing_subscriber::util::SubscriberInitExt;
+use ws_tool::{codec::default_string_check_fn, ClientBuilder};
 
 /// websocket client connect to binance futures websocket
 #[derive(StructOpt)]
@@ -14,22 +17,27 @@ struct Args {
 
 #[tokio::main]
 async fn main() -> Result<(), ()> {
-    pretty_env_logger::init();
+    tracing_subscriber::fmt::fmt()
+        .with_max_level(Level::DEBUG)
+        .finish()
+        .try_init()
+        .expect("failed to init log");
     let args = Args::from_args();
     let channels = args.channels.join("/");
-    let mut builder = ConnBuilder::new(&format!(
+    let mut builder = ClientBuilder::new(&format!(
         "wss://fstream.binance.com/stream?streams={}",
         channels
     ));
     if let Some(proxy) = args.proxy {
         builder = builder.proxy(&proxy)
     }
-    let mut client = builder.build().await.unwrap();
-    client.handshake().await.unwrap();
+    let mut client = builder
+        .connect_with_check(default_string_check_fn)
+        .await
+        .unwrap();
 
-    loop {
-        let resp = client.read_frame().await.unwrap();
-        let msg = String::from_utf8(resp.payload_data_unmask().to_vec()).unwrap();
+    while let Some(Ok((_, msg))) = client.next().await {
         println!("{}", msg.trim());
     }
+    Ok(())
 }
